donkey
======

|Build Status| |Coverage| |pypi| |license|

Like `make`_ but for the 21st century.

TODO:
* coloured logging
* tests

.. |Build Status| image:: https://travis-ci.org/samuelcolvin/donkey.svg?branch=master
   :target: https://travis-ci.org/samuelcolvin/donkey
.. |Coverage| image:: https://codecov.io/gh/samuelcolvin/donkey/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/samuelcolvin/donkey
.. |pypi| image:: https://img.shields.io/pypi/v/donkey-make.svg
   :target: https://pypi.python.org/pypi/donkey-make
.. |license| image:: https://img.shields.io/pypi/l/donkey-make.svg
   :target: https://github.com/samuelcolvin/donkey/blob/master/LICENSE
.. _make: http://helpmanual.io/man1/make/
